# Installation
`labrea-test` is available for install via pip.

```bash
pip install labrea-test
````

Alternatively, you can install the latest development version from GitHub.

```bash
pip install git+https://github.com/8451/labrea-test@develop
```
